@@ -1,9 +1,6 @@
 /* system.h: system-dependent declarations; include this first.
-   $Id: system.h 6348 2015-06-20 08:06:47Z eliz $
 
-   Copyright 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
-   2006, 2007, 2008, 2009, 2010, 2011, 2012, 2014
-   Free Software Foundation, Inc.
+   Copyright 1997-2022 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -44,6 +41,8 @@
 #include <getopt.h>
 #include <unistd.h>
 
+#include <fcntl.h>
+
 /* For gettext (NLS).  */
 #include "gettext.h"
 
@@ -70,9 +69,8 @@ extern int errno;
 extern char *strerror ();
 #endif
 
-#ifdef HAVE_LIMITS_H
 #include <limits.h>
-#endif
+
 #ifndef PATH_MAX
 #ifndef _POSIX_PATH_MAX
 # define _POSIX_PATH_MAX 255
@@ -80,10 +78,6 @@ extern char *strerror ();
 #define PATH_MAX _POSIX_PATH_MAX
 #endif
 
-#ifndef HAVE_DECL_STRCOLL
-extern int strcoll ();
-#endif
-
 #include <sys/stat.h>
 #if STAT_MACROS_BROKEN
 # undef S_ISDIR
@@ -92,22 +86,6 @@ extern int strcoll ();
 # define S_ISDIR(mode) (((mode) & S_IFMT) == S_IFDIR)
 #endif
 
-#ifdef HAVE_SYS_FILE_H
-#include <sys/file.h>
-#endif /* HAVE_SYS_FILE_H */
-
-#ifndef O_RDONLY
-/* Since <fcntl.h> is POSIX, prefer that to <sys/fcntl.h>.
-   This also avoids some useless warnings on (at least) Linux.  */
-#ifdef HAVE_FCNTL_H
-#include <fcntl.h>
-#else /* not HAVE_FCNTL_H */
-#ifdef HAVE_SYS_FCNTL_H
-#include <sys/fcntl.h>
-#endif /* not HAVE_SYS_FCNTL_H */
-#endif /* not HAVE_FCNTL_H */
-#endif /* not O_RDONLY */
-
 /* MS-DOS and similar non-Posix systems have some peculiarities:
     - they distinguish between binary and text files;
     - they use both `/' and `\\' as directory separator in file names;
@@ -137,10 +115,6 @@ extern int strcoll ();
 #   define HAVE_LONG_FILENAMES(dir)  (pathconf (dir, _PC_NAME_MAX) > 12)
 #   define NULL_DEVICE	"/dev/null"
 #   define DEFAULT_INFOPATH "c:/djgpp/info;/usr/local/info;/usr/info;."
-    /* DJGPP supports /dev/null, which is okay for Unix aficionados,
-       shell scripts and Makefiles, but interactive DOS die-hards
-       would probably want to have NUL as well.  */
-#   define ALSO_NULL_DEVICE  "NUL"
 #  else  /* O_BINARY && !__DJGPP__ */
 #   define HAVE_LONG_FILENAMES(dir)  (0)
 #   define NULL_DEVICE	"NUL"
@@ -204,11 +178,6 @@ extern int kill (pid_t, int);
 # define PIPE_USE_FORK	1
 #endif /* not O_BINARY */
 
-/* Everything but DJGPP.  */
-#ifndef ALSO_NULL_DEVICE
-# define ALSO_NULL_DEVICE  ""
-#endif
-
 #ifdef HAVE_PWD_H
 #include <pwd.h>
 #endif
