@@ -14,7 +14,6 @@ $result_trees{'space_in_anchor'} = {
             {
               'contents' => [
                 {
-                  'parent' => {},
                   'text' => 'anchor  name'
                 }
               ],
@@ -22,7 +21,6 @@ $result_trees{'space_in_anchor'} = {
                 'spaces_after_argument' => '   ',
                 'spaces_before_argument' => '   '
               },
-              'parent' => {},
               'type' => 'brace_command_arg'
             }
           ],
@@ -33,7 +31,6 @@ $result_trees{'space_in_anchor'} = {
             ],
             'normalized' => 'anchor-name'
           },
-          'parent' => {},
           'source_info' => {
             'file_name' => '',
             'line_nr' => 1,
@@ -43,28 +40,19 @@ $result_trees{'space_in_anchor'} = {
         {
           'contents' => [
             {
-              'parent' => {},
               'text' => '.
 '
             }
           ],
-          'parent' => {},
           'type' => 'paragraph'
         }
       ],
-      'parent' => {},
       'type' => 'before_node_section'
     }
   ],
   'type' => 'document_root'
 };
-$result_trees{'space_in_anchor'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'space_in_anchor'}{'contents'}[0]{'contents'}[0]{'args'}[0];
-$result_trees{'space_in_anchor'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'space_in_anchor'}{'contents'}[0]{'contents'}[0];
 $result_trees{'space_in_anchor'}{'contents'}[0]{'contents'}[0]{'extra'}{'node_content'}[0] = $result_trees{'space_in_anchor'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0];
-$result_trees{'space_in_anchor'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'space_in_anchor'}{'contents'}[0];
-$result_trees{'space_in_anchor'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'space_in_anchor'}{'contents'}[0]{'contents'}[1];
-$result_trees{'space_in_anchor'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'space_in_anchor'}{'contents'}[0];
-$result_trees{'space_in_anchor'}{'contents'}[0]{'parent'} = $result_trees{'space_in_anchor'};
 
 $result_texis{'space_in_anchor'} = '@anchor{   anchor  name   }.
 ';
