@@ -8,7 +8,6 @@ use utf8;
 $result_trees{'acronym_in_node_and_section'} = {
   'contents' => [
     {
-      'parent' => {},
       'type' => 'before_node_section'
     },
     {
@@ -16,7 +15,6 @@ $result_trees{'acronym_in_node_and_section'} = {
         {
           'contents' => [
             {
-              'parent' => {},
               'text' => 'top'
             }
           ],
@@ -24,7 +22,6 @@ $result_trees{'acronym_in_node_and_section'} = {
             'spaces_after_argument' => '
 '
           },
-          'parent' => {},
           'type' => 'line_arg'
         }
       ],
@@ -44,7 +41,6 @@ $result_trees{'acronym_in_node_and_section'} = {
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
       'source_info' => {
         'file_name' => '',
         'line_nr' => 1,
@@ -56,7 +52,6 @@ $result_trees{'acronym_in_node_and_section'} = {
         {
           'contents' => [
             {
-              'parent' => {},
               'text' => 'top'
             }
           ],
@@ -64,14 +59,12 @@ $result_trees{'acronym_in_node_and_section'} = {
             'spaces_after_argument' => '
 '
           },
-          'parent' => {},
           'type' => 'line_arg'
         }
       ],
       'cmdname' => 'top',
       'contents' => [
         {
-          'parent' => {},
           'text' => '
 ',
           'type' => 'empty_line'
@@ -80,7 +73,6 @@ $result_trees{'acronym_in_node_and_section'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
       'source_info' => {
         'file_name' => '',
         'line_nr' => 2,
@@ -92,7 +84,6 @@ $result_trees{'acronym_in_node_and_section'} = {
         {
           'contents' => [
             {
-              'parent' => {},
               'text' => 'chap'
             }
           ],
@@ -100,7 +91,6 @@ $result_trees{'acronym_in_node_and_section'} = {
             'spaces_after_argument' => '
 '
           },
-          'parent' => {},
           'type' => 'line_arg'
         }
       ],
@@ -120,7 +110,6 @@ $result_trees{'acronym_in_node_and_section'} = {
         'normalized' => 'chap',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
       'source_info' => {
         'file_name' => '',
         'line_nr' => 4,
@@ -132,7 +121,6 @@ $result_trees{'acronym_in_node_and_section'} = {
         {
           'contents' => [
             {
-              'parent' => {},
               'text' => 'chap'
             }
           ],
@@ -140,14 +128,12 @@ $result_trees{'acronym_in_node_and_section'} = {
             'spaces_after_argument' => '
 '
           },
-          'parent' => {},
           'type' => 'line_arg'
         }
       ],
       'cmdname' => 'chapter',
       'contents' => [
         {
-          'parent' => {},
           'text' => '
 ',
           'type' => 'empty_line'
@@ -156,7 +142,6 @@ $result_trees{'acronym_in_node_and_section'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
       'source_info' => {
         'file_name' => '',
         'line_nr' => 5,
@@ -168,7 +153,6 @@ $result_trees{'acronym_in_node_and_section'} = {
         {
           'contents' => [
             {
-              'parent' => {},
               'text' => 'sec define'
             }
           ],
@@ -176,7 +160,6 @@ $result_trees{'acronym_in_node_and_section'} = {
             'spaces_after_argument' => '
 '
           },
-          'parent' => {},
           'type' => 'line_arg'
         }
       ],
@@ -196,7 +179,6 @@ $result_trees{'acronym_in_node_and_section'} = {
         'normalized' => 'sec-define',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
       'source_info' => {
         'file_name' => '',
         'line_nr' => 7,
@@ -208,7 +190,6 @@ $result_trees{'acronym_in_node_and_section'} = {
         {
           'contents' => [
             {
-              'parent' => {},
               'text' => 'define'
             }
           ],
@@ -216,14 +197,12 @@ $result_trees{'acronym_in_node_and_section'} = {
             'spaces_after_argument' => '
 '
           },
-          'parent' => {},
           'type' => 'line_arg'
         }
       ],
       'cmdname' => 'section',
       'contents' => [
         {
-          'parent' => {},
           'text' => '
 ',
           'type' => 'empty_line'
@@ -235,29 +214,24 @@ $result_trees{'acronym_in_node_and_section'} = {
                 {
                   'contents' => [
                     {
-                      'parent' => {},
                       'text' => 'GHJ'
                     }
                   ],
-                  'parent' => {},
                   'type' => 'brace_command_arg'
                 },
                 {
                   'contents' => [
                     {
-                      'parent' => {},
                       'text' => 'Good Hypo Jolly'
                     }
                   ],
                   'extra' => {
                     'spaces_before_argument' => ' '
                   },
-                  'parent' => {},
                   'type' => 'brace_command_arg'
                 }
               ],
               'cmdname' => 'acronym',
-              'parent' => {},
               'source_info' => {
                 'file_name' => '',
                 'line_nr' => 10,
@@ -265,16 +239,13 @@ $result_trees{'acronym_in_node_and_section'} = {
               }
             },
             {
-              'parent' => {},
               'text' => '
 '
             }
           ],
-          'parent' => {},
           'type' => 'paragraph'
         },
         {
-          'parent' => {},
           'text' => '
 ',
           'type' => 'empty_line'
@@ -283,7 +254,6 @@ $result_trees{'acronym_in_node_and_section'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
       'source_info' => {
         'file_name' => '',
         'line_nr' => 8,
@@ -295,7 +265,6 @@ $result_trees{'acronym_in_node_and_section'} = {
         {
           'contents' => [
             {
-              'parent' => {},
               'text' => 'sec here is '
             },
             {
@@ -303,16 +272,13 @@ $result_trees{'acronym_in_node_and_section'} = {
                 {
                   'contents' => [
                     {
-                      'parent' => {},
                       'text' => 'GHJ'
                     }
                   ],
-                  'parent' => {},
                   'type' => 'brace_command_arg'
                 }
               ],
               'cmdname' => 'acronym',
-              'parent' => {},
               'source_info' => {
                 'file_name' => '',
                 'line_nr' => 12,
@@ -324,7 +290,6 @@ $result_trees{'acronym_in_node_and_section'} = {
             'spaces_after_argument' => '
 '
           },
-          'parent' => {},
           'type' => 'line_arg'
         }
       ],
@@ -346,7 +311,6 @@ $result_trees{'acronym_in_node_and_section'} = {
         'normalized' => 'sec-here-is-GHJ',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
       'source_info' => {
         'file_name' => '',
         'line_nr' => 12,
@@ -358,7 +322,6 @@ $result_trees{'acronym_in_node_and_section'} = {
         {
           'contents' => [
             {
-              'parent' => {},
               'text' => 'here is '
             },
             {
@@ -366,16 +329,13 @@ $result_trees{'acronym_in_node_and_section'} = {
                 {
                   'contents' => [
                     {
-                      'parent' => {},
                       'text' => 'GHJ'
                     }
                   ],
-                  'parent' => {},
                   'type' => 'brace_command_arg'
                 }
               ],
               'cmdname' => 'acronym',
-              'parent' => {},
               'source_info' => {
                 'file_name' => '',
                 'line_nr' => 13,
@@ -387,14 +347,12 @@ $result_trees{'acronym_in_node_and_section'} = {
             'spaces_after_argument' => '
 '
           },
-          'parent' => {},
           'type' => 'line_arg'
         }
       ],
       'cmdname' => 'section',
       'contents' => [
         {
-          'parent' => {},
           'text' => '
 ',
           'type' => 'empty_line'
@@ -402,7 +360,6 @@ $result_trees{'acronym_in_node_and_section'} = {
         {
           'contents' => [
             {
-              'parent' => {},
               'text' => 'In text '
             },
             {
@@ -410,16 +367,13 @@ $result_trees{'acronym_in_node_and_section'} = {
                 {
                   'contents' => [
                     {
-                      'parent' => {},
                       'text' => 'GHJ'
                     }
                   ],
-                  'parent' => {},
                   'type' => 'brace_command_arg'
                 }
               ],
               'cmdname' => 'acronym',
-              'parent' => {},
               'source_info' => {
                 'file_name' => '',
                 'line_nr' => 15,
@@ -427,19 +381,16 @@ $result_trees{'acronym_in_node_and_section'} = {
               }
             },
             {
-              'parent' => {},
               'text' => '.
 '
             }
           ],
-          'parent' => {},
           'type' => 'paragraph'
         }
       ],
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
       'source_info' => {
         'file_name' => '',
         'line_nr' => 13,
@@ -449,65 +400,16 @@ $result_trees{'acronym_in_node_and_section'} = {
   ],
   'type' => 'document_root'
 };
-$result_trees{'acronym_in_node_and_section'}{'contents'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'};
-$result_trees{'acronym_in_node_and_section'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[1]{'args'}[0];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[1];
 $result_trees{'acronym_in_node_and_section'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'acronym_in_node_and_section'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'acronym_in_node_and_section'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'acronym_in_node_and_section'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[1]{'parent'} = $result_trees{'acronym_in_node_and_section'};
-$result_trees{'acronym_in_node_and_section'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[2]{'args'}[0];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[2];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[2];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[2]{'parent'} = $result_trees{'acronym_in_node_and_section'};
-$result_trees{'acronym_in_node_and_section'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[3]{'args'}[0];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[3];
 $result_trees{'acronym_in_node_and_section'}{'contents'}[3]{'extra'}{'node_content'}[0] = $result_trees{'acronym_in_node_and_section'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'acronym_in_node_and_section'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'acronym_in_node_and_section'}{'contents'}[3]{'args'}[0]{'contents'}[0];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[3]{'parent'} = $result_trees{'acronym_in_node_and_section'};
-$result_trees{'acronym_in_node_and_section'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[4]{'args'}[0];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[4];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[4]{'contents'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[4];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[4]{'parent'} = $result_trees{'acronym_in_node_and_section'};
-$result_trees{'acronym_in_node_and_section'}{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[5]{'args'}[0];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[5];
 $result_trees{'acronym_in_node_and_section'}{'contents'}[5]{'extra'}{'node_content'}[0] = $result_trees{'acronym_in_node_and_section'}{'contents'}[5]{'args'}[0]{'contents'}[0];
 $result_trees{'acronym_in_node_and_section'}{'contents'}[5]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'acronym_in_node_and_section'}{'contents'}[5]{'args'}[0]{'contents'}[0];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[5]{'parent'} = $result_trees{'acronym_in_node_and_section'};
-$result_trees{'acronym_in_node_and_section'}{'contents'}[6]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[6]{'args'}[0];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[6]{'args'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[6];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[6]{'contents'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[6];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[6]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[6]{'contents'}[1]{'contents'}[0]{'args'}[0];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[6]{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[6]{'contents'}[1]{'contents'}[0];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[6]{'contents'}[1]{'contents'}[0]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[6]{'contents'}[1]{'contents'}[0]{'args'}[1];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[6]{'contents'}[1]{'contents'}[0]{'args'}[1]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[6]{'contents'}[1]{'contents'}[0];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[6]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[6]{'contents'}[1];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[6]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[6]{'contents'}[1];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[6]{'contents'}[1]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[6];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[6]{'contents'}[2]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[6];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[6]{'parent'} = $result_trees{'acronym_in_node_and_section'};
-$result_trees{'acronym_in_node_and_section'}{'contents'}[7]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[7]{'args'}[0];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[7]{'args'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[7]{'args'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[7]{'args'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[7]{'args'}[0]{'contents'}[1];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[7]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[7]{'args'}[0];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[7]{'args'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[7];
 $result_trees{'acronym_in_node_and_section'}{'contents'}[7]{'extra'}{'node_content'}[0] = $result_trees{'acronym_in_node_and_section'}{'contents'}[7]{'args'}[0]{'contents'}[0];
 $result_trees{'acronym_in_node_and_section'}{'contents'}[7]{'extra'}{'node_content'}[1] = $result_trees{'acronym_in_node_and_section'}{'contents'}[7]{'args'}[0]{'contents'}[1];
 $result_trees{'acronym_in_node_and_section'}{'contents'}[7]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'acronym_in_node_and_section'}{'contents'}[7]{'args'}[0]{'contents'}[0];
 $result_trees{'acronym_in_node_and_section'}{'contents'}[7]{'extra'}{'nodes_manuals'}[0]{'node_content'}[1] = $result_trees{'acronym_in_node_and_section'}{'contents'}[7]{'args'}[0]{'contents'}[1];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[7]{'parent'} = $result_trees{'acronym_in_node_and_section'};
-$result_trees{'acronym_in_node_and_section'}{'contents'}[8]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[8]{'args'}[0];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[8]{'args'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[8]{'args'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[8]{'args'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[8]{'args'}[0]{'contents'}[1];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[8]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[8]{'args'}[0];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[8]{'args'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[8];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[8]{'contents'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[8];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[8]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[8]{'contents'}[1];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[8]{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[8]{'contents'}[1]{'contents'}[1]{'args'}[0];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[8]{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[8]{'contents'}[1]{'contents'}[1];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[8]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[8]{'contents'}[1];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[8]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[8]{'contents'}[1];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[8]{'contents'}[1]{'parent'} = $result_trees{'acronym_in_node_and_section'}{'contents'}[8];
-$result_trees{'acronym_in_node_and_section'}{'contents'}[8]{'parent'} = $result_trees{'acronym_in_node_and_section'};
 
 $result_texis{'acronym_in_node_and_section'} = '@node top
 @top top
