@@ -1,29 +1,28 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'bye'} = {
   'contents' => [
+    {
+      'type' => 'before_node_section'
+    },
     {
       'args' => [
         {
-          'parent' => {},
           'text' => '
 ',
           'type' => 'misc_arg'
         }
       ],
-      'cmdname' => 'bye',
-      'parent' => {}
+      'cmdname' => 'bye'
     }
   ],
-  'type' => 'text_root'
+  'type' => 'document_root'
 };
-$result_trees{'bye'}{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'bye'}{'contents'}[0];
-$result_trees{'bye'}{'contents'}[0]{'parent'} = $result_trees{'bye'};
 
 $result_texis{'bye'} = '@bye
 ';
@@ -34,4 +33,7 @@ $result_texts{'bye'} = '';
 $result_errors{'bye'} = [];
 
 
+$result_floats{'bye'} = {};
+
+
 1;
