@@ -1,75 +1,64 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text);
+   %result_elements %result_directions_text %result_indices_sort_strings);
 
 use utf8;
 
 $result_trees{'two_unnumbered_no_argument'} = {
   'contents' => [
     {
-      'contents' => [],
-      'parent' => {},
-      'type' => 'text_root'
+      'contents' => [
+        {
+          'contents' => [],
+          'type' => 'preamble_before_content'
+        }
+      ],
+      'type' => 'before_node_section'
     },
     {
       'args' => [
         {
-          'contents' => [],
           'extra' => {
             'spaces_after_argument' => '
 '
           },
-          'parent' => {},
           'type' => 'line_arg'
         }
       ],
       'cmdname' => 'unnumbered',
-      'contents' => [],
       'extra' => {
         'missing_argument' => 1
       },
-      'level' => 1,
-      'line_nr' => {
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     },
     {
       'args' => [
         {
-          'contents' => [],
           'extra' => {
             'spaces_after_argument' => '
 '
           },
-          'parent' => {},
           'type' => 'line_arg'
         }
       ],
       'cmdname' => 'unnumbered',
-      'contents' => [],
       'extra' => {
         'missing_argument' => 1
       },
-      'level' => 1,
-      'line_nr' => {
+      'source_info' => {
         'file_name' => '',
         'line_nr' => 2,
         'macro' => ''
-      },
-      'parent' => {}
+      }
     }
   ],
   'type' => 'document_root'
 };
-$result_trees{'two_unnumbered_no_argument'}{'contents'}[0]{'parent'} = $result_trees{'two_unnumbered_no_argument'};
-$result_trees{'two_unnumbered_no_argument'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'two_unnumbered_no_argument'}{'contents'}[1];
-$result_trees{'two_unnumbered_no_argument'}{'contents'}[1]{'parent'} = $result_trees{'two_unnumbered_no_argument'};
-$result_trees{'two_unnumbered_no_argument'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'two_unnumbered_no_argument'}{'contents'}[2];
-$result_trees{'two_unnumbered_no_argument'}{'contents'}[2]{'parent'} = $result_trees{'two_unnumbered_no_argument'};
 
 $result_texis{'two_unnumbered_no_argument'} = '@unnumbered
 @unnumbered
@@ -79,36 +68,42 @@ $result_texis{'two_unnumbered_no_argument'} = '@unnumbered
 $result_texts{'two_unnumbered_no_argument'} = '';
 
 $result_sectioning{'two_unnumbered_no_argument'} = {
-  'level' => 0,
-  'section_childs' => [
-    {
-      'cmdname' => 'unnumbered',
-      'extra' => {
-        'missing_argument' => 1
+  'structure' => {
+    'section_childs' => [
+      {
+        'cmdname' => 'unnumbered',
+        'extra' => {
+          'missing_argument' => 1
+        },
+        'structure' => {
+          'section_level' => 1,
+          'section_up' => {}
+        }
       },
-      'level' => 1,
-      'section_up' => {}
-    },
-    {
-      'cmdname' => 'unnumbered',
-      'extra' => {
-        'missing_argument' => 1
-      },
-      'level' => 1,
-      'section_prev' => {},
-      'section_up' => {},
-      'toplevel_prev' => {}
-    }
-  ]
+      {
+        'cmdname' => 'unnumbered',
+        'extra' => {
+          'missing_argument' => 1
+        },
+        'structure' => {
+          'section_level' => 1,
+          'section_prev' => {},
+          'section_up' => {},
+          'toplevel_prev' => {}
+        }
+      }
+    ],
+    'section_level' => 0
+  }
 };
-$result_sectioning{'two_unnumbered_no_argument'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'two_unnumbered_no_argument'};
-$result_sectioning{'two_unnumbered_no_argument'}{'section_childs'}[1]{'section_prev'} = $result_sectioning{'two_unnumbered_no_argument'}{'section_childs'}[0];
-$result_sectioning{'two_unnumbered_no_argument'}{'section_childs'}[1]{'section_up'} = $result_sectioning{'two_unnumbered_no_argument'};
-$result_sectioning{'two_unnumbered_no_argument'}{'section_childs'}[1]{'toplevel_prev'} = $result_sectioning{'two_unnumbered_no_argument'}{'section_childs'}[0];
+$result_sectioning{'two_unnumbered_no_argument'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'two_unnumbered_no_argument'};
+$result_sectioning{'two_unnumbered_no_argument'}{'structure'}{'section_childs'}[1]{'structure'}{'section_prev'} = $result_sectioning{'two_unnumbered_no_argument'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'two_unnumbered_no_argument'}{'structure'}{'section_childs'}[1]{'structure'}{'section_up'} = $result_sectioning{'two_unnumbered_no_argument'};
+$result_sectioning{'two_unnumbered_no_argument'}{'structure'}{'section_childs'}[1]{'structure'}{'toplevel_prev'} = $result_sectioning{'two_unnumbered_no_argument'}{'structure'}{'section_childs'}[0];
 
 $result_errors{'two_unnumbered_no_argument'} = [
   {
-    'error_line' => ':1: warning: @unnumbered missing argument
+    'error_line' => 'warning: @unnumbered missing argument
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -117,7 +112,7 @@ $result_errors{'two_unnumbered_no_argument'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => ':2: warning: @unnumbered missing argument
+    'error_line' => 'warning: @unnumbered missing argument
 ',
     'file_name' => '',
     'line_nr' => 2,
@@ -135,7 +130,7 @@ $result_floats{'two_unnumbered_no_argument'} = {};
 $result_converted{'plaintext'}->{'two_unnumbered_no_argument'} = '';
 
 
-$result_converted{'html'}->{'two_unnumbered_no_argument'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
+$result_converted{'html'}->{'two_unnumbered_no_argument'} = '<!DOCTYPE html>
 <html>
 <!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
 <head>
@@ -148,31 +143,12 @@ $result_converted{'html'}->{'two_unnumbered_no_argument'} = '<!DOCTYPE html PUBL
 <meta name="distribution" content="global">
 <meta name="viewport" content="width=device-width,initial-scale=1">
 
-<style type="text/css">
-<!--
-a.copiable-anchor {visibility: hidden; text-decoration: none; line-height: 0em}
-a.summary-letter {text-decoration: none}
-blockquote.indentedblock {margin-right: 0em}
-div.display {margin-left: 3.2em}
-div.example {margin-left: 3.2em}
-kbd {font-style: oblique}
-pre.display {font-family: inherit}
-pre.format {font-family: inherit}
-pre.menu-comment {font-family: serif}
-pre.menu-preformatted {font-family: serif}
-span.nolinebreak {white-space: nowrap}
-span.roman {font-family: initial; font-weight: normal}
-span.sansserif {font-family: sans-serif; font-weight: normal}
-span:hover a.copiable-anchor {visibility: visible}
-ul.no-bullet {list-style: none}
--->
-</style>
 
 
 </head>
 
 <body lang="en">
-<hr>
+
 
 
 </body>
