@@ -18,6 +18,24 @@ check_need_recoded_file_names ()
    return 0
 }
 
+# Some tests use non-ASCII characters on their command line,
+# using UTF-8 to encode those characters in the source files.
+# Shell on Windows may consider those characters to be
+# encoded in the current codeset, passing them incorrectly to
+# the programs, and even if the shell passed them unchanged, native
+# Windows perl in most cases cannot cope with non-ASCII arguments
+# encoded in a different encoding than the current user codepage.
+check_need_command_line_unicode ()
+{
+  if echo "$remaining" | grep 'Need command-line unicode' >/dev/null; then
+    if test "z$HOST_IS_WINDOWS_VARIABLE" = 'zyes' ; then
+      echo "S: (no reliable command-line Unicode) $current"
+       return 1
+    fi
+  fi
+  return 0
+}
+
 check_latex2html_and_tex4ht ()
 {
     use_latex2html=no
@@ -209,6 +227,22 @@ if sed 1q input_file_names_recoded_stamp.txt | grep 'OK' >/dev/null; then
   no_recoded_file_names=no
 fi
 
+# In Windows the recoding of file name is not reliable, as the file name may
+# be stored as UTF-16 using the user codepage to determine which codepage
+# the non-ASCII character comes from, and not the codepage that would have been
+# expected from the Perl code when creating the file, in
+# maintain/copy_change_file_name_encoding.pl and when determining the file name
+# to read in the tests (Latin1 in the current case).  Note that if the user
+# codepage is an encoding in which the character exists and is converted to and
+# from UTF-16 as the byte expected in Latin1, some tests may succeed even if
+# the characters shown and the locales used are not the ones expected.
+# However, if the character does not exist in the encoding, for instance in
+# case of multibyte encoding the character may not reliably be be converted to
+# a file name and read, so we skip the tests.
+if test "z$HOST_IS_WINDOWS_VARIABLE" = 'zyes' ; then
+  no_recoded_file_names=yes
+fi
+
 one_test=no
 if test -n "$1"; then
   one_test=yes
@@ -351,6 +385,7 @@ while read line; do
 
     skipped_test=no
     check_need_recoded_file_names || skipped_test=yes
+    check_need_command_line_unicode || skipped_test=yes
     check_latex2html_and_tex4ht || skipped_test=yes
     if [ "$skipped_test" = 'yes' ] ; then
       if test $one_test = 'yes' ; then
